@@ -2,6 +2,7 @@
 #include "noerr.h"
 #include <unistd.h>
 #include <errno.h>
+#include <stdlib.h>
 
 int close_noerr(int fd)
 {
@@ -41,3 +42,10 @@ int unlink_noerr(const char *pathname)
 	errno = saved_errno;
 	return ret;
 }
+
+void free_noerr(void *p)
+{
+	int saved_errno = errno;
+	free(p);
+	errno = saved_errno;
+}
